@@ -33,7 +33,7 @@ switch ($params['mode'])
 {
 	case 'delete':
 		$deleted = Gbook_utils::DeleteEntry($params['entryid']);
-		$params = $deleted ? array('tab_message'=> 'itemdeleted', 'active_tab' => 'items') : array('errors' => lang('failure'), 'active_tab' => 'items');
+		$params = $deleted ? array('tab_message'=> 'itemdeleted', 'active_tab' => 'items', 'filter' => $params['filter']) : array('errors' => lang('failure'), 'active_tab' => 'items', 'filter' => $params['filter']);
 		$this->Redirect($id, 'defaultadmin', '', $params);
 		break;
 
@@ -41,7 +41,7 @@ switch ($params['mode'])
 	case 'edit':
 		if( !isset($params['entryid']) )
 		{
-			$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries', 'errors' => lang('missingparams'));
+			$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries', 'filter' => $params['filter'], 'errors' => lang('missingparams'));
 			$this->Redirect($id, 'defaultadmin', '', $params);
 			return;
 		}
@@ -49,7 +49,7 @@ switch ($params['mode'])
 		if( $_SERVER['REQUEST_METHOD'] == 'POST' && isset($params['submit']) )
 		{
 			$edited = Gbook_utils::EditEntry($params['entryid'], $params['gbookid'], $params['name'], $params['email'], $params['title'], $params['message'], $params['notify'], $params['active']);
-			$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'items');
+			$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'items', 'filter' => $params['filter']);
 			if ( $edited )
 			{
 				$params['tab_message'] = 'itemupdated';
@@ -73,7 +73,7 @@ switch ($params['mode'])
 		$this->SendEvent('Gbook_entry_edited', $item);
 				
 		//Update search index
-		$search = cms_utils::get_module('Search');
+		$search = cms_utils::get_search_module();
 		if ( $search != false && $item->active == 1 )
 		{
 			$search->AddWords($this->GetName(), $params['entryid'], 'entry', $item->title . ' ' . $item->rawmessage);
@@ -83,7 +83,7 @@ switch ($params['mode'])
 			$search->DeleteWords($this->GetName(), $params['entryid'], 'entry');
 		}
 
-		$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries');
+		$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries', 'filter' => $params['filter']);
 		$this->Redirect($id, 'defaultadmin', '', $params);
 		break;
 
@@ -102,13 +102,14 @@ switch ($params['mode'])
 		$this->SendEvent('Gbook_entry_edited', $item);
 				
 		//Update search index
-		$search = cms_utils::get_module('Search');
+		$search = cms_utils::get_search_module();
 		if ( $search != false )
 		{
 			$search->AddWords($this->GetName(), $params['entryid'], 'entry', $item->title . ' ' . $item->rawmessage);
 		}
+		Gbook_utils::UpdateAllSpamrates();
 
-		$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries');
+		$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries', 'filter' => $params['filter']);
 		$this->Redirect($id, 'defaultadmin', '', $params);
 		break;
 
@@ -127,13 +128,14 @@ switch ($params['mode'])
 		$this->SendEvent('Gbook_entry_edited', $item);
 				
 		//Update search index
-		$search = cms_utils::get_module('Search');
+		$search = cms_utils::get_search_module();
 		if ( $search != false )
 		{
 			$search->DeleteWords($this->GetName(), $params['entryid'], 'entry');
 		}
+		Gbook_utils::UpdateAllSpamrates();
 
-		$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries');
+		$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries', 'filter' => $params['filter']);
 		$this->Redirect($id, 'defaultadmin', '', $params);
 		break;
 
@@ -147,7 +149,8 @@ switch ($params['mode'])
 								approved_by = ?
 							WHERE entry_id = ?";
 		$db->Execute($query, array(0, get_userid(), $params['entryid']));
-		$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries');
+		Gbook_utils::UpdateAllSpamrates();
+		$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries', 'filter' => $params['filter']);
 		$this->Redirect($id, 'defaultadmin', '', $params);
 		break;
 
@@ -161,7 +164,8 @@ switch ($params['mode'])
 								approved_by = ?
 							WHERE entry_id = ?";
 		$db->Execute($query, array(0, get_userid(), $params['entryid']));
-		$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries');
+		Gbook_utils::UpdateAllSpamrates();
+		$params = array('gbookid' => $params['gbookid'], 'active_tab' => 'entries', 'filter' => $params['filter']);
 		$this->Redirect($id, 'defaultadmin', '', $params);
 		break;
 
@@ -191,14 +195,14 @@ if ( !empty($item) )
 		// marked as HAM
 		$smarty->assign('approvelink', $this->CreateLink($id, 'edititem', $returnid,
 				    '<img src="../modules/Gbook/images/nospam.gif" class="systemicon" alt="' . $this->Lang('deletefromham') . '"> ' . $this->Lang('deletefromham'),
-				    array ('gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'mode'=>'deletefromham')));
+				    array ('gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'mode'=>'deletefromham', 'filter' => $params['filter'])));
 	}
 	elseif ( $item->approved == 2 )
 	{
 		// marked as SPAM
 		$smarty->assign('approvelink', $this->CreateLink($id, 'edititem', $returnid,
 				    '<img src="../modules/Gbook/images/nospam.gif" class="systemicon" alt="' . $this->Lang('deletefromspam') . '"> ' . $this->Lang('deletefromspam'),
-				    array ('gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'mode'=>'deletefromspam')));
+				    array ('gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'mode'=>'deletefromspam', 'filter' => $params['filter'])));
 	}
 	else	
 	{
@@ -206,11 +210,11 @@ if ( !empty($item) )
 		$smarty->assign('approvelink', 
 						$this->CreateLink($id, 'edititem', $returnid,
 				    '<img src="../modules/Gbook/images/check.png" class="systemicon" alt="' . $this->Lang('saveasham') . '"> ' . $this->Lang('saveasham'),
-				    array ('gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'mode'=>'saveasham'))
+				    array ('gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'mode'=>'saveasham', 'filter' => $params['filter']))
 						. ' &nbsp; ' .
 						$this->CreateLink($id, 'edititem', $returnid,
 				    '<img src="../modules/Gbook/images/nospam.gif" class="systemicon" alt="' . $this->Lang('saveasspam') . '"> ' . $this->Lang('saveasspam'),
-				    array ('gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'mode'=>'saveasspam'))
+				    array ('gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'mode'=>'saveasspam', 'filter' => $params['filter']))
 					);
 	}
 
@@ -218,7 +222,7 @@ if ( !empty($item) )
 	//$smarty->assign('apply',$params['mode'] == 'add' ? '' : $this->CreateInputSubmit($id, 'applybutton', $this->Lang('apply')));
 	$smarty->assign('cancel',$this->CreateInputSubmit ($id, 'cancel', lang('cancel')));
 
-	$params = array('mode' => 'edit', 'gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'notify' => $item->notify, 'active' => $item->active);
+	$params = array('mode' => 'edit', 'gbookid' => $params['gbookid'], 'entryid' => $item->entry_id, 'notify' => $item->notify, 'active' => $item->active, 'filter' => $params['filter']);
 	$smarty->assign('formstart', $this->CreateFormStart ($id, 'edititem', $returnid, 'post', '', false, '', $params));
 	$smarty->assign('formend',$this->CreateFormEnd());
 
