@@ -80,7 +80,7 @@ switch ($params['mode'])
 		$query = "DELETE FROM " . cms_db_prefix() . "module_gbook_smileys WHERE smiley_id = ?";
 		$db->Execute($query, array($params['smileyid']));
 		
-		@unlink('../modules/gbook/smileys/' . $smileys[$params['smileyid']]['smiley_file']);
+		@unlink('../modules/Gbook/smileys/' . $smileys[$params['smileyid']]['smiley_file']);
 
 		$params = array('active_tab' => 'smileys');
 		$this->Redirect($id, 'defaultadmin', '', $params);
@@ -111,7 +111,7 @@ switch ($params['mode'])
 			$fileext = strtolower(substr($rawfilename, strrpos($rawfilename, '.') + 1));
 			if ( in_array($fileext, $allowedext) )
 			{
-				if ( cms_move_uploaded_file($_FILES[$id.'addsmiley']['tmp_name'], '../modules/gbook/smileys/' . $filename . '.' . $fileext) )
+				if ( cms_move_uploaded_file($_FILES[$id.'addsmiley']['tmp_name'], '../modules/Gbook/smileys/' . $filename . '.' . $fileext) )
 				{
 					$query = "INSERT INTO ".cms_db_prefix()."module_gbook_smileys (smiley_file, smiley_code, sort, active) VALUES (?,?,?,?)";
 					$result = $db->Execute($query, array($filename . '.' . $fileext, '', count($smileys), 0));
