@@ -230,8 +230,6 @@ if ( $showform )
 		$template = 'form_tpl_' . $params['template'];
 	}
 		
-	// clear cache for this template
-	$smarty->clearCache($this->GetDatabaseResource($template));
 	echo $this->ProcessTemplateFromDatabase($template);
 }
 
