@@ -3,6 +3,7 @@ $lang['friendlyname'] = 'G&auml;steb&uuml;cher';
 $lang['moddescription'] = 'Erstellen und Verwalten von G&auml;steb&uuml;chern, um einige Nachrichten von Ihrer Website-Besuchern zu erhalten';
 $lang['description'] = 'Erhalte Nachrichten von Website-Besuchern';
 $lang['postinstall'] = 'Das Gbook Modul wurde erfolgreich installiert. Pr&uuml;fen Sie Inhalts-Bereich f&uuml;r &#039;%s&#039;.';
+$lang['spam'] = 'Spam';
 $lang['areyousure'] = 'Sind Sie sicher, dass Sie l&ouml;schen m&ouml;chten?';
 $lang['areyousuremulti'] = 'Sind Sie sicher das Sie diese Massenaktion ausf&uuml;hren wollen?';
 $lang['gbooks'] = 'G&auml;steb&uuml;cher';
@@ -24,10 +25,10 @@ $lang['admin_notification_message'] = 'Inhalt der Admin Benachrichtigung';
 $lang['required_fields'] = 'Pflichtangaben auf Frontend';
 $lang['import_csv'] = 'Importier Eintr&auml;ge von CSV-Datei';
 $lang['csv_format'] = 'CSV Format: &quot;author&quot;[string];&quot;email&quot;[string];&quot;title&quot;[string];&quot;message&quot;[string];&quot;ip&quot;[string];&quot;create_date&quot;[date/time:yyyy-mm-dd hh:mm:ss]';
-$lang['smileys'] = 'Smileys ';
-$lang['smiley'] = 'Smiley ';
+$lang['smileys'] = 'Smileys';
+$lang['smiley'] = 'Smiley';
 $lang['addsmiley'] = 'Smiley hinzuf&uuml;gen';
-$lang['id'] = 'ID ';
+$lang['id'] = 'ID';
 $lang['spamrate'] = 'Spam Bewertung';
 $lang['created'] = 'Eintragsdatum';
 $lang['modified'] = 'Ge&auml;ndert';
@@ -46,6 +47,10 @@ $lang['default_summary_template'] = 'Standard Listenansicht';
 $lang['default_detail_template'] = 'Standard Detailansichts';
 $lang['resetdefault'] = 'Template Laden/Zur&uuml;cksetzen';
 $lang['resetwarning'] = 'Sind Sie sicher das Sie dass Template zur&uuml;cksetzen m&ouml;chten?';
+$lang['title_custom_modulename'] = 'Benutzerdefinierte Modulname';
+$lang['help_custom_modulename'] = 'Sie k&ouml;nnen den Modulnamen hier &auml;ndern. Es wird als Titel der Modul Admin-Seiten und als Men&uuml; Text verwendet.';
+$lang['title_admin_section'] = 'Admin-Bereich';
+$lang['help_admin_section'] = 'W&auml;hlen Sie den Admin-Bereich (von Top-Level Admin Menu), wo dieses Modul zu geh&ouml;rt.';
 $lang['send_notifications_to'] = 'E-Mail-Adresse um Benachrichtigungen &uuml;ber neue Eintr&auml;ge zu erhalten';
 $lang['max_spamrate_active'] = 'Maximaler spamrating um ein Eintrag automatisch nach &Uuml;bermittlung zu aktivieren';
 $lang['max_spamrate_active_help'] = 'zwischen 0 und 1, Voreingestellt ist 0.6. Kleinerer Wert bedeutet strengere Einstellung.';
@@ -56,7 +61,7 @@ $lang['max_spamrate_save_help'] = 'zwischen 0 und 1, Voreingestellt ist 0.9. Kle
 $lang['badwords'] = 'Maskiere ungezogene W&ouml;rter (Komma getrennt)';
 $lang['optionsupdated'] = 'Die Einstellungen wurden aktualisiert.';
 $lang['entries'] = 'Eintr&auml;ge';
-$lang['name'] = 'Name ';
+$lang['name'] = 'Name';
 $lang['email'] = 'E-Mail';
 $lang['title'] = 'Titel';
 $lang['message'] = 'Nachricht';
@@ -68,16 +73,15 @@ $lang['not_allowed_to_post_twice'] = '<p>Entschuldigung. Durch Spam-Schutz ist e
 <p>Bitte versuchen Sie es sp&auml;ter noch einmal oder senden Sie uns eine E-Mail, damit wir Ihre Nachricht an unsere Website hinzuf&uuml;gen k&ouml;nnen.</p>';
 $lang['submission_response_cnt'] = '<p>Vielen Dank. Ihre Nachricht wurde eingetragen.</p>';
 $lang['submission_response_spam_cnt'] = '<p>Vielen Dank f&uuml;r Ihre Eintrag.</p>
-<p>Ihr Eintrag wird nach &Uuml;berpr&uuml;fung durch den Administrator im G&auml;stebuch angezeigt.</p>
-';
+<p>Ihr Eintrag wird nach &Uuml;berpr&uuml;fung durch den Administrator im G&auml;stebuch angezeigt.</p>';
 $lang['admin_notification_subject_cnt'] = 'Neue G&auml;stebucheintrag';
 $lang['admin_notification_message_cnt'] = 'Sie haben eine neue Nachricht erhalten in Ihrem {sitename} G&auml;stebuch.
 
 &Uuml;berpr&uuml;fen Sie es auf: {root_url}';
-$lang['help_action'] = 'Possible values: <ul><li>&#039;default&#039; - for displaying the guestbook entries</li><li>&#039;form&#039; - for displaying a form</li><li>&#039;detail&#039; - for displaying a single entry, e.g. as search result</li></ul> ';
+$lang['help_action'] = 'Possible values: <ul><li>&#039;default&#039; - for displaying the guestbook entries</li><li>&#039;form&#039; - for displaying a form</li><li>&#039;detail&#039; - for displaying a single entry, e.g. as search result</li></ul>';
 $lang['help_alias'] = 'Use another guestbook than the default one. Check the Guestbooks-tab, column &#039;Tags&#039;, to see which aliases can be used.';
-$lang['help_entryid'] = 'Use this parameter along with <code>action=&#039;detail&#039;</code> if you want to display only one guestbook entry. To get the latest entry, use <code>entryid=-1</code> ';
-$lang['help_template'] = 'Use another template than the default one. Note that templates must be of the proper type, in accordance with the action parameter. ';
+$lang['help_entryid'] = 'Use this parameter along with <code>action=&#039;detail&#039;</code> if you want to display only one guestbook entry. To get the latest entry, use <code>entryid=-1</code>';
+$lang['help_template'] = 'Use another template than the default one. Note that templates must be of the proper type, in accordance with the action parameter.';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>The Gbook module provides your site visitors a convenient way to give some feedback on your site. Messages can include smileys and your guestbook is effectively protected from spam without the necessity of using an annoying captcha.</p>
 <h3>How Do I Use It</h3>
@@ -119,11 +123,9 @@ Users must belong to a group with the &#039;Gbook: Modify&#039; permission to be
 </ul>
 
 <h3>Feedback</h3>
-<p>If you enjoy this module, use it on a commercial website or would like to encourage future development, you might consider just a small donation.<br />Or leave a message in the <a href="http://forum.cmsmadesimple.org/viewtopic.php?f=7&amp;t=64460">Gbook forum topic</a>. Any kind of feedback will be much appreciated.</p>
-';
-$lang['utmz'] = '156861353.1355837206.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utma'] = '156861353.238888043.1355837206.1355837206.1355837206.1';
-$lang['qca'] = 'P0-802263609-1268423862699';
-$lang['utmb'] = '156861353';
+<p>If you enjoy this module, use it on a commercial website or would like to encourage future development, you might consider just a small donation.<br />Or leave a message in the <a href="http://forum.cmsmadesimple.org/viewtopic.php?f=7&amp;t=64460">Gbook forum topic</a>. Any kind of feedback will be much appreciated.</p>';
+$lang['utma'] = '156861353.1834246644.1386548232.1386548232.1386548232.1';
+$lang['utmz'] = '156861353.1386548232.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/search.php|utmcmd=referral';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
