@@ -11,6 +11,9 @@
 
 if (!isset($gCms)) exit;
 
+$db = $this->GetDb();
+$taboptarray = array('mysql' => 'ENGINE=MyISAM');
+$dict = NewDataDictionary($db);
 
 switch( $oldversion )
 {
@@ -23,8 +26,20 @@ switch( $oldversion )
 		//current_version: 1.1
 
 	case "1.1":
+		$this->CreateEvent('Gbook_entry_deleted');
+		$sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_gbook_entries", "spamrate I");
+		$dict->ExecuteSQLArray($sqlarray);
+
+		//current_version: 1.2
 		
-		//current_version: 1.1.1
+	case "1.2":
+		if ( $this->GetPreference('send_notifications_to') == '' )
+		{
+			$send_notifications_to[0] = get_userid();
+			$this->SetPreference('send_notifications_to', serialize($send_notifications_to));
+		}
+		
+		//current_version: 2.0.2
 		
 }
 
